@@ -1117,16 +1117,27 @@ class TestERP5Diff(unittest.TestCase):
     old_xml = """
 <ul>
   <node/>blablabla
+  <node>AAA<blank/>BBB</node>
+  <node>AAA<blank/>BBB</node>
+  <node>AAA<blank/>BBB<blank/>BBB</node>CCC
 </ul>
 """
     new_xml = """
 <ul>
   <node/>yayaya
+  <node>C<blank/>BBB</node>
+  <node>AAA<blank/>D</node>
+  <node>AAA<blank/>BBB<blank/>E</node>F
 </ul>
 """
     expected_result_string = """<xupdate:modifications xmlns:xupdate="http://www.xmldb.org/xupdate" version="1.0">
-  <xupdate:update select="/ul"><node/>yayaya
+  <xupdate:update select="/ul/text()[1]">yayaya
+  </xupdate:update>
+  <xupdate:update select="/ul/node[2]/text()[1]">C</xupdate:update>
+  <xupdate:update select="/ul/node[3]/text()[2]">D</xupdate:update>
+  <xupdate:update select="/ul/text()[2]">F
 </xupdate:update>
+  <xupdate:update select="/ul/node[4]/text()[3]">E</xupdate:update>
 </xupdate:modifications>
 """
     self._assertERP5DiffWorks(old_xml, new_xml, expected_result_string)
